<!--
  meiroku.xsl, ver.1.2
  written by Toshinobu OGISO & Asuko KONDO
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="/">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="magazine">
    <html xmlns:xhtml="http://www.w3.org/1999/xhtml">
      <head>
        <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <meta http-equiv="Content-Style-Type" content="text/css"/>
        <style>
          body{
              background:ivory;
              overflow-x:scroll;
              overflow-y:auto;
          }
          .magazine_title{
              color:white;
              font-family:'ＭＳ Ｐゴシック', sans-serif;
              font-size:16pt;
              font-weight:bold;
              line-height:2;
              background-color:navy;
              padding:1em;
          }
          .honmon{
              font-size:14pt;
              font-family:'ＭＳ Ｐ明朝', serif;
              line-height:2.5;
          }
          .article{
              border:thin solid gray;
              margin:1em;
              padding:1em;
          }
          .article_title{
              color:white;
              font-family:'ＭＳ Ｐゴシック', sans-serif;
              font-size:14pt;
              font-weight:bold;
              line-height:2;
              background-color:royalblue;
              margin:0.5em 0em;
              padding:0.5em 1em;
          }
          .target_string{
              color:magenta;
              font-weight:bold;
          }
          .figureBlock{
              padding:1.5em 0em 1.5em 1em;
          }
          .figureBlock span{
              color:grey;
              font-size:11pt;
              font-family:'ＭＳ Ｐゴシック', sans-serif;
              font-weight:bold;
              border:medium solid gray;
              padding:2em 5em;
          }
          .s{
              font-weight:bold;
          }
          .warigaki{
              font-size:11pt;
          }
          .pb{
              font-size:11pt;
              font-family:'ＭＳ Ｐゴシック', sans-serif;
              font-weight:bold;
              color:gray;
          }
          .gap{
              border:thin solid gray;
              cursor:pointer;
          }
          .r{
              font-size:8pt;
              vertical-align:super;
          }
          .lr{
              font-size:8pt;
              vertical-align:sub;
          }
          q.suw{
              color:black;
              cursor:pointer;
              quotes:"" ""
          }
          q.quote{
              color:black;
              background-color:palegreen;
              border:thin solid darkgreen;
              margin:0.2em;
              padding:0.3em;
              cursor:pointer;
              quotes:"" "";
          }
          q q.quote{
              color:black;
              border:thin solid darkgreen;
              margin:0.1em;
              padding:0.1em;
              cursor:pointer;
          }
          .chu{
              font-size:10pt;
              color:red;
              vertical-align:super;
              cursor:pointer;
          }</style>
        <title><xsl:value-of select="@title"/><xsl:value-of select="@issue"/>号
        </title>
      </head>
      <body>
        <div class="honmon">
          <div class="magazine_title"><xsl:value-of select="@title"
            /><xsl:value-of select="@issue"/>号（<xsl:value-of select="@year"/>年） </div>
          <xsl:apply-templates/>
        </div>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="titleBlock">
    <div class="article">
      <xsl:apply-templates/>
    </div>
  </xsl:template>
  <xsl:template match="article">
    <div class="article">
      <div class="article_title"><xsl:value-of select="@title"
        /><xsl:text>　</xsl:text><xsl:value-of select="@author"/><xsl:if
        test="@originalAuthor!=''">；<xsl:value-of select="@originalAuthor"
        /></xsl:if><xsl:text>　</xsl:text>（<xsl:value-of select="@style"
        /><xsl:text>　</xsl:text><xsl:value-of select="@script"/>）</div>
      <xsl:apply-templates/>
    </div>
  </xsl:template>
  <xsl:template match="tg">
    <a class="target_string">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
      <xsl:apply-templates/>
    </a>
  </xsl:template>
  <xsl:template match="p|block">
    <xsl:apply-templates/>
    <br/>
  </xsl:template>
  <xsl:template match="figureBlock">
    <div class="figureBlock">
      <span>図表</span>
    </div>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="warigaki">
    <span class="warigaki">
      <xsl:apply-templates/>
    </span>
  </xsl:template>
  <xsl:template match="quotation">
    <xsl:choose>
      <xsl:when test="@style">
        <q class="quote" title="引用 種類={@type} ソース={@source} 文体={@style}">
          <xsl:apply-templates/>
        </q>
      </xsl:when>
      <xsl:otherwise>
        <q class="quote" title="引用 種類={@type} ソース={@source}">
          <xsl:apply-templates/>
        </q>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="s">
    <xsl:apply-templates/>
    <span class="s">|</span>
  </xsl:template>
  <xsl:template match="odoriji">
    <xsl:apply-templates/>
    <span class="chu" title="踊字 原文={@originalText}">※</span>
  </xsl:template>
  <xsl:template match="gap">
    <xsl:apply-templates/>
    <span class="gap" title="判読不可 文字数={@quantity}"/>
  </xsl:template>
  <xsl:template match="pb">
    <xsl:apply-templates/>
    <span class="pb">（<xsl:value-of select="@originalN"/>）</span>
  </xsl:template>
  <xsl:template match="SUW">
    <span>
      <q class="suw"
        title="形態論情報　語順序：{@orderID}　書字形出現形：{@orthToken}　語彙素読み：{@lForm}　語彙素：{@lemma}　語彙素細分類：{@subLemma}　語種：{@wType}　品詞：{@pos}　活用形：{@cType}　活用型：{@cForm}　語形：{@form}　発音形出現形：{@pronToken}"
        >|<xsl:apply-templates/></q>
    </span>
  </xsl:template>
  <xsl:template match="ruby">
    <xsl:apply-templates/>
    <span class="r">
      <xsl:value-of select="@rubyText"/>
    </span>
  </xsl:template>
  <xsl:template match="lRuby">
    <xsl:apply-templates/>
    <span class="lr">
      <xsl:value-of select="@rubyText"/>
    </span>
  </xsl:template>
  <xsl:template match="corr">
    <xsl:choose>
      <xsl:when test="@subType='ruby'">
        <xsl:apply-templates/>
        <span class="chu" title="{@type} ルビ原文={@originalText}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="@type='erratum'">
          <xsl:apply-templates/>
          <span class="chu" title="誤字 原文={@originalText}">※</span>
        </xsl:if>
        <xsl:if test="@type='excess'">
          <xsl:apply-templates/>
          <span class="chu" title="衍字 原文={@originalText}">※</span>
        </xsl:if>
        <xsl:if test="@type='omission'">
          <xsl:apply-templates/>
          <span class="chu" title="脱字">※</span>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="unclear">
    <xsl:apply-templates/>
    <span class="chu" title="不鮮明">※</span>
  </xsl:template>
  <xsl:template match="vMark">
    <xsl:choose>
      <xsl:when test="@type='ruby'">
        <xsl:apply-templates/>
        <span class="chu" title="濁点無表記 ルビ原文={@originalText}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
        <span class="chu" title="濁点無表記">※</span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="g">
    <xsl:choose>
      <xsl:when test="@type='外字'">
        <xsl:apply-templates/>
        <span class="chu" title="{@type} 字形説明={@ref}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
        <span class="chu" title="{@type}">※</span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="kanbun">
    <xsl:if test="@type='返読前'">
      <xsl:apply-templates/>
      <span class="chu" title="{@type} 原文={@originalText} ID={@id}">※</span>
    </xsl:if>
    <xsl:if test="@type='返読後'">
      <xsl:apply-templates/>
      <span class="chu" title="{@type} ID={@id}">※</span>
    </xsl:if>
    <xsl:if test="@type='補読'">
      <xsl:apply-templates/>
      <span class="chu" title="{@type}">※</span>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>
