<!--
  meiroku_morph.xsl, ver.1.1
  written by Toshinobu OGISO & Asuko KONDO
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="/">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="magazine">
    <html xmlns:xhtml="http://www.w3.org/1999/xhtml">
      <head>
        <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <meta http-equiv="Content-Style-Type" content="text/css" />
        <style>
          body{background:ivory;overflow-x: scroll;overflow-y:auto;}
          table{float:none;width:100%;border:2px gray solid;border-collapse:collapse;}
          td{border:2px gray solid;border-collapse:collapse;font-size:14pt;font-family:'ＭＳ Ｐ明朝',serif;line-height:1.2;}
          th{border:2px gray solid;border-collapse:collapse;font-size:11pt;}
          .magazine_title{color:white;font-family:'ＭＳ Ｐゴシック',sans-serif;font-size:16pt;font-weight:bold;line-height:2;background-color:navy;margin:1em 0em;padding:1em}
          .article_title{color:white;font-family:'ＭＳ Ｐゴシック',sans-serif;font-size:14pt;font-weight:bold;line-height:2;background-color:royalblue;margin:1em 0em 0.5em 0em;padding:0.5em 1em}
          .target_string{color:magenta;font-weight:bold;}
          .suw{}
          .r{font-size:8pt;vertical-align:super}
          .lr{font-size:8pt;vertical-align:sub}

        </style>
        <title>
          <xsl:value-of select="@title"/><xsl:value-of select="@issue"/>号
        </title>
      </head>
      <body>
        <div class="magazine_title">
          <xsl:value-of select="@title"/><xsl:value-of select="@issue"/>号（<xsl:value-of select="@year"/>年）
        </div>
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>
  
  <xsl:template match="titleBlock">
    <table>
      <tr>
        <th>語連番</th>
        <th>ページ</th>
        <th>文頭</th>
        <th>書字形出現形</th>
        <th>語彙素読み</th>
        <th>語彙素</th>
        <th>語彙素細分類</th>
        <th>語種</th>
        <th>品詞</th>
        <th>活用型</th>
        <th>活用形</th>
        <th>語形</th>
        <th>発音形出現形</th>
        <th>引用種類</th>
        <th>引用ソース</th>
        <th>引用文体</th>
      </tr>
      <xsl:apply-templates/>
    </table>
  </xsl:template>  

  <xsl:template match="article">
    <div class="article_title">
      <xsl:value-of select="@title"/>　　<xsl:value-of select="@author"/><xsl:if test="@originalAuthor!=''">；<xsl:value-of select="@originalAuthor"/></xsl:if>　　（<xsl:value-of select="@style"/>　<xsl:value-of select="@script"/>）
    </div>
    <table>
      <tr>
        <th>語連番</th>
        <th>ページ</th>
        <th>文頭</th>
        <th>書字形出現形</th>
        <th>語彙素読み</th>
        <th>語彙素</th>
        <th>語彙素細分類</th>
        <th>語種</th>
        <th>品詞</th>
        <th>活用型</th>
        <th>活用形</th>
        <th>語形</th>
        <th>発音形出現形</th>
        <th>引用種類</th>
        <th>引用ソース</th>
        <th>引用文体</th>
      </tr>
      <xsl:apply-templates/>
    </table>
  </xsl:template>
  
  <xsl:template match="SUW">
    <tr class="suw">
      <td align="right"><xsl:value-of select="@orderID"/></td>
      <td align="right"><a href="http://db3.ninjal.ac.jp/ninjaldl/convert.php?title=meirokuzassi&amp;size=50&amp;issue={ancestor::magazine/@issue}&amp;chou={translate(preceding::pb[position()=1]/@originalN,'オウ','ou')}" target="_blank"><xsl:value-of select="preceding::pb[position()=1]/@originalN"/></a></td>
      <td align="center">
        <xsl:choose>
          <xsl:when test="@BOS='True'">B</xsl:when>
          <xsl:otherwise>I</xsl:otherwise>
        </xsl:choose>
      </td>
      <td><xsl:apply-templates/></td>
      <td><xsl:value-of select="@lForm"/></td>
      <td><xsl:value-of select="@lemma"/></td>
      <td><xsl:value-of select="@subLemma"/></td>
      <td><xsl:value-of select="@wType"/></td>
      <td><xsl:value-of select="@pos"/></td>
      <td><xsl:value-of select="@cType"/></td>
      <td><xsl:value-of select="@cForm"/></td>
      <td><xsl:value-of select="@form"/></td>
      <td><xsl:value-of select="@pronToken"/></td>
      <td><xsl:value-of select="ancestor::quotation/@type"/></td>
      <td><xsl:value-of select="ancestor::quotation/@source"/></td>
      <td><xsl:value-of select="ancestor::quotation/@style"/></td>
    </tr>
  </xsl:template>

  <xsl:template match="tg">
    <a class="target_string">
    <xsl:attribute name="id">
      <xsl:value-of select="@id"/>
    </xsl:attribute>
      <xsl:apply-templates/>
    </a>
  </xsl:template>


  <xsl:template match="ruby">
    <xsl:apply-templates/>
    <span class="r">
      <xsl:value-of select="@rubyText"/>
    </span>
  </xsl:template>
  
  <xsl:template match="lRuby">
    <xsl:apply-templates/>
    <span class="lr">
      <xsl:value-of select="@rubyText"/>
    </span>
  </xsl:template>
  
</xsl:stylesheet>
